@@ -1,5 +1,5 @@
 /*
- *Copyright (C) 2004-2006 Qball Cow <Qball@qballcow.nl>
+ *Copyright (C) 2004-2007 Qball Cow <qball@sarine.nl>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,7 +25,6 @@
 #include <string.h>
 #include <glade/glade.h>
 #include <time.h>
-#include <config.h>
 #include "main.h"
 #include "misc.h"
 #include "playlist3.h"
@@ -36,11 +35,12 @@
 GladeXML *xml_esf  = NULL;
 GtkTextBuffer *buffer= NULL;
 
+void esf_reload(void);
 
-void esf_render_example(GtkTextBuffer *buffer)
+static void esf_render_example(GtkTextBuffer *buffer)
 {
 	char *filename = _("/path/to/file_name.mp3");
-	char *artist = _("I'm Artist");
+	char *artist = _("Jonny Singer");
 	char *album = _("Sing or Swing you want");
 	char *title = _("The kernel jazz");
 	char *track = _("01/24");
@@ -88,15 +88,10 @@ void esf_render_example(GtkTextBuffer *buffer)
 	gtk_label_set_text(GTK_LABEL(glade_xml_get_widget(xml_esf, "label_example")), (const char *)result_buffer);
 	mpd_freeSong(song);
 }
-
-void esf_reload()
+void esf_reload(void)
 {
 	esf_render_example(buffer);
 }
-
-
-
-
 char * edit_song_markup(char *format)
 {
 	char *str_format = NULL;
@@ -104,7 +99,7 @@ char * edit_song_markup(char *format)
 	GtkWidget *dialog;
 	char *path = gmpc_get_full_glade_path("gmpc.glade");
 	xml_esf= glade_xml_new(path, "esf_dialog",NULL);
-	g_free(path);
+	q_free(path);
 	dialog = glade_xml_get_widget(xml_esf, "esf_dialog");
 	buffer= gtk_text_view_get_buffer(GTK_TEXT_VIEW(glade_xml_get_widget(xml_esf, "textview_markup")));
 	glade_xml_signal_autoconnect (xml_esf);
@@ -113,7 +108,7 @@ char * edit_song_markup(char *format)
 	{
 		gtk_text_buffer_set_text(buffer, format, -1);
 	}
-	g_free(str_format);
+	q_free(str_format);
 
 	switch(gtk_dialog_run(GTK_DIALOG(dialog)))
 	{
