@@ -28,6 +28,7 @@
 #include "playlist-list.h"
 #include "mpdinteraction.h"
 #include "tray-icon.h"
+#include "gmpc-profiles.h"
 
 /**
  * Some gobjects
@@ -70,6 +71,8 @@ extern gmpcPlugin url_plugin;
 /** main.c **/
 extern GladeXML *xml_main_window;
 extern MpdObj *connection;
+extern GmpcProfiles *gmpc_profiles;
+
 
 enum{
 	TIME_FORMAT_ELAPSED,
@@ -133,4 +136,8 @@ void preferences_show_pref_window(int plugin_id);
  */
 #define q_free(a) g_free(a);a=NULL;
 
+/* help */
+void info2_activate(void);
+void info2_fill_artist_view(char *);
+void info2_fill_album_view(char *, char *);
 #endif
