@@ -6,6 +6,7 @@
 #include "config1.h"
 #include "mpdinteraction.h"
 
+static int ignore = FALSE;
 extern GtkWidget *pl3_cp_tree;
 
 /* old stuff */
@@ -45,8 +46,10 @@ void update_preferences_information(void);
 void connection_profiles_changed(GtkComboBox *combo, gpointer data);
 void connection_add_profile(void);
 void connection_remove_profile(void);
-
-static gchar *current = NULL;
+void submenu_artist_clicked(GtkWidget *item);
+void submenu_album_clicked(GtkWidget *item);
+void submenu_genre_clicked(GtkWidget *item);
+void submenu_dir_clicked(GtkWidget *item);
 
 gmpcPlugin server_plug = {
 	"Server Settings", 	/** name */
@@ -124,7 +127,6 @@ int connect_to_mpd()
 	 */
 	string = connection_get_hostname();
 	mpd_set_hostname(connection,string);
-	cfg_free_string(string);
 	/** 
 	 * Set port
 	 */
@@ -138,7 +140,6 @@ int connect_to_mpd()
 	{
 		string = connection_get_password();
 		mpd_set_password(connection,string);
-		cfg_free_string(string);
 	}
 	else
 	{
@@ -396,6 +397,109 @@ static void xfade_update()
 
 }
 
+/**
+ * Helper functions
+ */
+void play_path(const gchar *path)
+{
+	if(path)
+	{
+		if(mpd_server_check_command_allowed(connection, "playlistfind")== MPD_SERVER_COMMAND_ALLOWED)
+		{
+			MpdData *data = NULL;
+			mpd_playlist_search_start(connection,TRUE);
+			mpd_playlist_search_add_constraint(connection, MPD_TAG_ITEM_FILENAME,path);
+			data = mpd_playlist_search_commit(connection);
+			if(data)
+			{
+				mpd_player_play_id(connection, data->song->id);
+				mpd_data_free(data);
+				return;
+			}
+		}
+		if(mpd_server_check_command_allowed(connection, "addid") == MPD_SERVER_COMMAND_ALLOWED){
+			int songid = mpd_playlist_add_get_id(connection, (gchar *)path);
+			if(songid >= 0) {
+				mpd_player_play_id(connection, songid);
+			}
+		}
+	}
+}
+
+void add_artist(const gchar *artist)
+{
+	MpdData *data = NULL;
+	/* Check artist */
+	g_return_if_fail(artist != NULL);
+
+	mpd_database_search_start(connection,TRUE);
+	mpd_database_search_add_constraint(connection, MPD_TAG_ITEM_ARTIST,artist);
+	data = mpd_database_search_commit(connection);
+	if(data)
+	{
+		for(;data;data = mpd_data_get_next(data))
+		{
+			mpd_playlist_queue_add(connection, data->song->file);
+		}
+		mpd_playlist_queue_commit(connection);
+	}
+}
+void add_album(const gchar *artist,const gchar *album)
+{
+	MpdData *data = NULL;
+	/* Check artist */
+	g_return_if_fail(artist != NULL);
+	g_return_if_fail(album != NULL);
+
+	mpd_database_search_start(connection,TRUE);
+	mpd_database_search_add_constraint(connection, MPD_TAG_ITEM_ARTIST,artist);
+	mpd_database_search_add_constraint(connection, MPD_TAG_ITEM_ALBUM,album);
+	data = mpd_database_search_commit(connection);
+	if(data)
+	{
+		for(;data;data = mpd_data_get_next(data))
+		{
+			mpd_playlist_queue_add(connection, data->song->file);
+		}
+		mpd_playlist_queue_commit(connection);
+	}
+}
+void add_genre(const gchar *genre)
+{
+	MpdData *data = NULL;
+	/* Check artist */
+	g_return_if_fail(genre != NULL);
+
+	mpd_database_search_start(connection,TRUE);
+	mpd_database_search_add_constraint(connection, MPD_TAG_ITEM_GENRE,genre);
+	data = mpd_database_search_commit(connection);
+	if(data)
+	{
+		for(;data;data = mpd_data_get_next(data))
+		{
+			mpd_playlist_queue_add(connection, data->song->file);
+		}
+		mpd_playlist_queue_commit(connection);
+	}
+}
+
+void add_directory(const gchar *path)
+{
+	gchar *dirpath = g_path_get_dirname(path);
+	MpdData *data =  mpd_database_get_directory(connection,dirpath);
+	printf("dir: %s from path: %s\n", dirpath, path);
+	for(;data;data = mpd_data_get_next(data))
+	{
+		if(data->type == MPD_DATA_TYPE_SONG)
+		{
+			mpd_playlist_queue_add(connection, data->song->file);
+		}
+	}
+	mpd_playlist_queue_commit(connection);
+	g_free(dirpath);
+}
+
+
 
 void ServerStatusChangedCallback(MpdObj *mi, ChangedStatusType what, void *userdata)
 {
@@ -408,8 +512,6 @@ void ServerStatusChangedCallback(MpdObj *mi, ChangedStatusType what, void *userd
 
 
 
-
-
 static void server_pref_destroy(GtkWidget *container)
 {
 	if(server_pref_xml)
@@ -491,12 +593,12 @@ void entry_auth_changed(GtkEntry *entry)
 	GtkComboBox *combo = (GtkComboBox *)glade_xml_get_widget(connection_pref_xml, "cb_profiles");
 	GtkTreeIter iter;
 	GtkListStore *store = (GtkListStore *)gtk_combo_box_get_model(combo);
+	if(ignore) return;
 	if(gtk_combo_box_get_active_iter(combo,&iter))
 	{
 		gchar *value= NULL, *uid = NULL;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
-		cfg_set_single_value_as_string(profiles, uid,"password",
-			(char *)gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "entry_auth"))));
+    gmpc_profiles_set_password(gmpc_profiles, uid, (char *)gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "entry_auth"))));
 		q_free(uid);
 		q_free(value);
 	}
@@ -507,13 +609,14 @@ void auth_enable_toggled(GtkToggleButton *but)
 	GtkComboBox *combo = (GtkComboBox *) glade_xml_get_widget(connection_pref_xml, "cb_profiles");
 	GtkTreeIter iter;
 	GtkTreeModel *store = gtk_combo_box_get_model(combo);
+	if(ignore) return;
 	if(gtk_combo_box_get_active_iter(combo,&iter))
 	{
 		char *value= NULL, *uid = NULL;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
-		cfg_set_single_value_as_int(profiles, uid, "useauth",gtk_toggle_button_get_active(but));
+    gmpc_profiles_set_do_auth(gmpc_profiles, uid, gtk_toggle_button_get_active(but));
 		gtk_widget_set_sensitive(glade_xml_get_widget(connection_pref_xml, "entry_auth"), 
-				cfg_get_single_value_as_int_with_default(profiles, uid,"useauth",0));	
+				gmpc_profiles_get_do_auth(gmpc_profiles, uid));	
 		q_free(uid);
 		q_free(value);
 	}
@@ -524,17 +627,17 @@ void update_preferences_name(void)
 	GtkComboBox *combo = (GtkComboBox *) glade_xml_get_widget(connection_pref_xml, "cb_profiles");
 	GtkTreeIter iter;
 	GtkTreeModel *store = gtk_combo_box_get_model(combo);
+	if(ignore) return;
 	if(gtk_combo_box_get_active_iter(combo,&iter))
 	{
 		char *value= NULL, *uid = NULL;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
-		cfg_set_single_value_as_string(profiles,uid,"name", 
+		gmpc_profiles_set_name(gmpc_profiles, uid,
 				(char *)gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "name_entry"))));
 		q_free(uid);
 		q_free(value);
 		value = (char *)gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "name_entry")));
 		gtk_list_store_set(GTK_LIST_STORE(store), &iter, 1, value, -1);
-		pl3_update_profiles_menu();
 	}
 }
 
@@ -543,11 +646,13 @@ void update_preferences_hostname(void)
 	GtkComboBox *combo = (GtkComboBox *) glade_xml_get_widget(connection_pref_xml, "cb_profiles");
 	GtkTreeIter iter;
 	GtkTreeModel *store = gtk_combo_box_get_model(combo);
+	if(ignore) return;
+
 	if(gtk_combo_box_get_active_iter(combo,&iter))
 	{
 		char *value= NULL, *uid = NULL;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
-		cfg_set_single_value_as_string(profiles,uid,"hostname", 
+		gmpc_profiles_set_hostname(gmpc_profiles, uid,
 				(char *)gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "hostname_entry"))));
 		q_free(uid);
 		q_free(value);
@@ -559,11 +664,12 @@ void update_preferences_portnumber(void)
 	GtkComboBox *combo = (GtkComboBox *) glade_xml_get_widget(connection_pref_xml, "cb_profiles");
 	GtkTreeIter iter;
 	GtkTreeModel *store = gtk_combo_box_get_model(combo);
+	if(ignore) return;
 	if(gtk_combo_box_get_active_iter(combo,&iter))
 	{
 		char *value= NULL, *uid = NULL;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
-		cfg_set_single_value_as_int(profiles, uid, "portnumber",
+		gmpc_profiles_set_port(gmpc_profiles, uid,
 				gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(glade_xml_get_widget(connection_pref_xml, "port_spin"))));
 		q_free(uid);
 		q_free(value);
@@ -606,7 +712,6 @@ void preferences_window_connect(GtkWidget *but)
 					if(!connect_to_mpd());
 				}
 				q_free(uid);
-				pl3_update_profiles_menu();
 			}
 		}
 	}
@@ -645,6 +750,9 @@ void connection_profiles_changed(GtkComboBox *combo, gpointer data)
 	{
 		char *value= NULL, *uid = NULL, *string;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
+
+		ignore = TRUE;
+
 		/**
 		 * Set name
 		 */
@@ -652,26 +760,29 @@ void connection_profiles_changed(GtkComboBox *combo, gpointer data)
 		/**
 		 * Set hostname
 		 */
-		string = cfg_get_single_value_as_string_with_default(profiles,uid,"hostname","localhost");
-		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "hostname_entry")), string);
-		cfg_free_string(string);
+		string = g_strdup(gmpc_profiles_get_hostname(gmpc_profiles, uid));
+		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "hostname_entry")), 
+				string);
+		g_free(string);
 		/**
 		 * Set port number 
 		 */
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(connection_pref_xml, "port_spin")), 
-				cfg_get_single_value_as_int_with_default(profiles,uid,"portnumber",6600));
+          gmpc_profiles_get_port(gmpc_profiles, uid));
 
 		/**
 		 * Set password check, and entry
 		 */
-		string = cfg_get_single_value_as_string_with_default(profiles, uid,"password", "");
+		string = g_strdup(gmpc_profiles_get_password(gmpc_profiles, uid));
 		gtk_toggle_button_set_active((GtkToggleButton *)
 				glade_xml_get_widget(connection_pref_xml, "ck_auth"), 
-				cfg_get_single_value_as_int_with_default(profiles, uid, "useauth", 0));
+          gmpc_profiles_get_do_auth(gmpc_profiles, uid));
 		gtk_widget_set_sensitive(glade_xml_get_widget(connection_pref_xml, "entry_auth"), 
-				cfg_get_single_value_as_int_with_default(profiles, uid, "useauth", 0));
-		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "entry_auth")),string);
-		cfg_free_string(string);
+          gmpc_profiles_get_do_auth(gmpc_profiles, uid));
+
+		gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(connection_pref_xml, "entry_auth")),/*string);*/
+          string);
+    g_free(string);
 
 		/**
 		 * Only enable the rmeove button when there is more then 1 profile
@@ -686,6 +797,7 @@ void connection_profiles_changed(GtkComboBox *combo, gpointer data)
 		}
 		q_free(value);
 		q_free(uid);
+		ignore = FALSE;
 	}
 
 }
@@ -695,13 +807,10 @@ void connection_add_profile(void)
 	GtkComboBox *combo = (GtkComboBox *) glade_xml_get_widget(connection_pref_xml, "cb_profiles");
 	GtkTreeIter iter;
 	GtkTreeModel *store = gtk_combo_box_get_model(combo);
-	gchar *value = g_strdup_printf("%u", g_random_int());
+	gchar *value = gmpc_profiles_create_new_item(gmpc_profiles, NULL); /*g_strdup_printf("%u", g_random_int());*/
 	gtk_list_store_append(GTK_LIST_STORE(store), &iter);
 	gtk_list_store_set(GTK_LIST_STORE(store), &iter, 0, value, 1, "Name", -1);
-	cfg_set_single_value_as_string(profiles,value,"name","Name");	
-	q_free(value);
 	gtk_combo_box_set_active_iter(GTK_COMBO_BOX(glade_xml_get_widget(connection_pref_xml, "cb_profiles")),&iter);
-	pl3_update_profiles_menu();
 }
 
 void connection_remove_profile(void)
@@ -713,20 +822,18 @@ void connection_remove_profile(void)
 	{
 		char *value= NULL, *uid = NULL;
 		gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &uid, 1,&value, -1);
-		cfg_remove_class(profiles,uid);
+    gmpc_profiles_remove_item(gmpc_profiles, uid);
 		gtk_list_store_remove(GTK_LIST_STORE(store), &iter);
 		q_free(uid);
 		q_free(value);
 		gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(connection_pref_xml, "cb_profiles")),0);
-		pl3_update_profiles_menu();
-		connection_set_current_profile(NULL);
 	}
 }
 
 static void connection_pref_construct(GtkWidget *container)
 {
 	gchar *def_profile = NULL;
-	conf_mult_obj *mult, *iter;
+	GList *mult, *iter;
 	GtkCellRenderer *renderer = NULL;
 	GtkListStore *store = NULL;
 	gchar *path = gmpc_get_full_glade_path("gmpc.glade");
@@ -738,42 +845,42 @@ static void connection_pref_construct(GtkWidget *container)
 	 * Profile selector
 	 * uid, name
 	 */
-	def_profile = connection_get_current_profile();
+	def_profile = gmpc_profiles_get_current(gmpc_profiles);
 	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 	gtk_combo_box_set_model(GTK_COMBO_BOX(glade_xml_get_widget(connection_pref_xml, "cb_profiles")), GTK_TREE_MODEL(store));
 	renderer = gtk_cell_renderer_text_new();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(connection_pref_xml, "cb_profiles")), renderer, TRUE);
 	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(glade_xml_get_widget(connection_pref_xml, "cb_profiles")), renderer, "text", 1, NULL);
 
-	mult = cfg_get_class_list(profiles);
+	mult = gmpc_profiles_get_profiles_ids(gmpc_profiles); 
 	if(mult)
 	{
 		int i = 0;
 		iter = mult;
 		do{
 			GtkTreeIter piter;
-			gchar *value = cfg_get_single_value_as_string_with_default(profiles, iter->key, "name", "Name");
+      gchar *value = gmpc_profiles_get_name(gmpc_profiles, (char *)iter->data); 
 			gtk_list_store_append(store, &piter);
-			gtk_list_store_set(store, &piter, 0,iter->key, 1,value,-1);
-			if(!strcmp(iter->key, def_profile))
+			gtk_list_store_set(store, &piter, 0,iter->data, 1,value,-1);
+			if(!strcmp((char *)(iter->data), def_profile))
 			{	
 				gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(connection_pref_xml, "cb_profiles")),i);
 			}
-			q_free(value);
-			iter = iter->next;
 			i++;
-		}while(iter);
-		cfg_free_multiple(mult);
+		}while((iter = g_list_next(iter)));
+    g_list_foreach(mult, (GFunc)g_free, NULL);
+    g_list_free(mult);
 	}
 	else{
-		GtkTreeIter piter;
+	/*	GtkTreeIter piter;
 		gchar *value = cfg_get_single_value_as_string_with_default(profiles, "Default", "name", "Default");
 		gtk_list_store_append(store, &piter);
 		gtk_list_store_set(store, &piter, 0,"Default", 1,value,-1);
 		q_free(value);
 		gtk_combo_box_set_active(GTK_COMBO_BOX(glade_xml_get_widget(connection_pref_xml, "cb_profiles")),0);
+*/
 	}
-
+  q_free(def_profile);
 
 	connection_profiles_changed(GTK_COMBO_BOX(glade_xml_get_widget(connection_pref_xml, "cb_profiles")),NULL);
 
@@ -803,91 +910,138 @@ static void connection_pref_construct(GtkWidget *container)
 }
 void connection_set_current_profile(const char *uid)
 {
-	if(current)
-	{
-		q_free(current);
-		current = NULL;
-	}
-	if(uid)
-	{
-		current = g_strdup(uid);
-		cfg_set_single_value_as_string(config, "connection", "currentprofile",(char *)uid);
-	}
+	gmpc_profiles_set_current(gmpc_profiles, uid);
 }
-char *connection_get_current_profile()
-{
-	gchar *value = NULL;
-	/**
-	 * Some hack to make it work even if the default value removed 
-	 */
-	if(!current)
-	{
-		current = cfg_get_single_value_as_string_with_default(config, "connection", "currentprofile", "Default");
-		value = cfg_get_single_value_as_string(profiles, current, "name");
-		/* if the default doesn't exists, start looking for the first profile */
-		if(!value)
-		{
-			conf_mult_obj *mult = cfg_get_class_list(profiles);
-			if(mult){
-				current = g_strdup(mult->key);
-				/**
-				 * update saved value
-				 */
-				cfg_set_single_value_as_string(config, "connection", "currentprofile",current);
-			}
-			cfg_free_multiple(mult);
-		}
-		else {
-			q_free(value);
-		}
-
-	}
-	return current;
-}
-
 void connection_set_password(char *password)
 {
-	gchar *profile = connection_get_current_profile();
+	gchar *profile = gmpc_profiles_get_current(gmpc_profiles);
 	/**
 	 * if NULL, or length 0, then disable, else set
 	 */ 
 	if(password && password[0] != '\0')
 	{
-		cfg_set_single_value_as_int(profiles, profile, "useauth", TRUE);
-		cfg_set_single_value_as_string(profiles, profile, "password", password);
+	  gmpc_profiles_set_password(gmpc_profiles, profile, password);
+	  gmpc_profiles_set_do_auth(gmpc_profiles, profile, TRUE);
 
 	}
 	else
 	{
-		cfg_set_single_value_as_int(profiles, profile, "useauth", FALSE);
+	  gmpc_profiles_set_password(gmpc_profiles, profile, NULL);
+	  gmpc_profiles_set_do_auth(gmpc_profiles, profile, FALSE);
 	}
 	q_free(profile);
 }
 
 int connection_use_auth()
 {
-	gchar *profile = connection_get_current_profile();
-	int retv = cfg_get_single_value_as_int_with_default(profiles, profile, "useauth",0);
-	return retv;
+  int retv;
+	gchar *profile = gmpc_profiles_get_current(gmpc_profiles);
+	retv  = gmpc_profiles_get_do_auth(gmpc_profiles, profile);
+  q_free(profile);
+  return retv;
 }
 
 char *connection_get_hostname()
 {
-	gchar *profile = connection_get_current_profile();
-	gchar *retv = cfg_get_single_value_as_string_with_default(profiles,profile,"hostname","localhost");
+	gchar *profile = gmpc_profiles_get_current(gmpc_profiles);
+	gchar *retv  = gmpc_profiles_get_hostname(gmpc_profiles, profile);
+  g_free(profile);
+
 	return retv;
 }
 int connection_get_port()
 {
-	gchar *profile = connection_get_current_profile();
-	int retv = cfg_get_single_value_as_int_with_default(profiles,profile,"portnumber", 6600);
+  int retv;
+	gchar *profile = gmpc_profiles_get_current(gmpc_profiles);
+	retv  = gmpc_profiles_get_port(gmpc_profiles, profile);
+  q_free(profile);
 	return retv;
 }
 char *connection_get_password()
 {
-	gchar *profile = connection_get_current_profile();
-	gchar *retv = cfg_get_single_value_as_string_with_default(profiles, profile,"password", "");
-	return retv;
+	gchar *profile = gmpc_profiles_get_current(gmpc_profiles);
+	gchar *retv  = gmpc_profiles_get_password(gmpc_profiles, profile);
+  g_free(profile);
+  return retv;
 }
 
+/**
+ * Helper menu functions *
+ */
+void submenu_artist_clicked(GtkWidget *item)
+{
+	gchar *artist = g_object_get_data(G_OBJECT(item), "artist");
+	add_artist(artist);	
+}
+void submenu_album_clicked(GtkWidget *item)
+{
+	gchar *artist = g_object_get_data(G_OBJECT(item), "artist");
+	gchar *album = g_object_get_data(G_OBJECT(item), "album");
+	add_album(artist,album);	
+}
+void submenu_genre_clicked(GtkWidget *item)
+{
+	gchar *genre = g_object_get_data(G_OBJECT(item), "genre");
+	add_genre(genre);	
+}
 
+void submenu_dir_clicked(GtkWidget *item)
+{
+	gchar *dir = g_object_get_data(G_OBJECT(item), "path");
+	add_directory(dir);	
+}
+void submenu_for_song(GtkWidget *menu, mpd_Song *song)
+{
+	GtkWidget *sitem;
+	GtkWidget *item;
+	GtkWidget *smenu;
+	smenu  = gtk_menu_new();
+	if(song->artist && song->album) 
+	{
+		/* Add all from artist */
+		sitem = gtk_image_menu_item_new_with_label(_("All from album"));
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(sitem), gtk_image_new_from_icon_name("media-album", GTK_ICON_SIZE_MENU));
+		g_object_set_data_full(G_OBJECT(sitem), "artist", g_strdup(song->artist), g_free);
+		g_object_set_data_full(G_OBJECT(sitem), "album", g_strdup(song->album), g_free);
+		g_signal_connect(G_OBJECT(sitem), "activate", G_CALLBACK(submenu_album_clicked), NULL);
+		gtk_menu_shell_append(GTK_MENU_SHELL(smenu), sitem);
+		gtk_widget_show(sitem);
+
+	}
+	if(song->artist )
+	{
+		/* Add all from album */
+		sitem = gtk_image_menu_item_new_with_label(_("All from artist"));
+		gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(sitem), gtk_image_new_from_icon_name("media-artist", GTK_ICON_SIZE_MENU));
+		g_object_set_data_full(G_OBJECT(sitem), "artist", g_strdup(song->artist), g_free);
+		g_signal_connect(G_OBJECT(sitem), "activate", G_CALLBACK(submenu_artist_clicked), NULL);
+		gtk_menu_shell_append(GTK_MENU_SHELL(smenu), sitem);
+		gtk_widget_show(sitem);
+	}
+	if(song->genre)
+	{
+		/* Add all from genre */
+		sitem = gtk_menu_item_new_with_label(_("All from genre"));
+		g_object_set_data_full(G_OBJECT(sitem), "genre", g_strdup(song->genre), g_free);
+		g_signal_connect(G_OBJECT(sitem), "activate", G_CALLBACK(submenu_genre_clicked), NULL);
+		gtk_menu_shell_append(GTK_MENU_SHELL(smenu), sitem);
+		gtk_widget_show(sitem);
+
+	}
+	/* Add all from file */
+	sitem = gtk_image_menu_item_new_with_label(_("All from same directory"));
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(sitem), gtk_image_new_from_icon_name("gtk-directory",GTK_ICON_SIZE_MENU));
+	g_object_set_data_full(G_OBJECT(sitem), "path", g_strdup(song->file), g_free);
+	g_signal_connect(G_OBJECT(sitem), "activate", G_CALLBACK(submenu_dir_clicked), NULL);
+	gtk_menu_shell_append(GTK_MENU_SHELL(smenu), sitem);
+	gtk_widget_show(sitem);
+	/* Create sub menu */
+	/* Add */
+	item = gtk_menu_item_new_with_label(_("Add more"));
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(item), smenu);
+	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
+	gtk_widget_show(item);
+	
+	gtk_widget_show(smenu);
+
+}
