@@ -53,6 +53,8 @@ static gboolean playlist_list_iter_nth_child(GtkTreeModel * tree_model,
 static gboolean playlist_list_iter_parent(GtkTreeModel * tree_model,
 		GtkTreeIter * iter,
 		GtkTreeIter * child);
+static void playlist_list_ref_node(GtkTreeModel *model, GtkTreeIter *iter);
+static void playlist_list_unref_node(GtkTreeModel *model, GtkTreeIter *iter);
 
 enum {
 	TOTAL_TIME_CHANGED,
@@ -593,6 +595,8 @@ static void playlist_list_tree_model_init(GtkTreeModelIface * iface)
 	iface->iter_n_children = playlist_list_iter_n_children;
 	iface->iter_nth_child = playlist_list_iter_nth_child;
 	iface->iter_parent = playlist_list_iter_parent;
+  iface->ref_node = playlist_list_ref_node;
+  iface->unref_node = playlist_list_unref_node;
 }
 
 /*****************************************************************************
@@ -612,6 +616,7 @@ static void playlist_list_init(CustomList * playlist_list)
 	playlist_list->column_types[PLAYLIST_LIST_COL_PLAYING] = G_TYPE_BOOLEAN;
 	playlist_list->column_types[PLAYLIST_LIST_COL_PLAYING_FONT_WEIGHT] = G_TYPE_INT;
 	playlist_list->column_types[PLAYLIST_LIST_COL_SONG_FILE] = G_TYPE_STRING;
+	playlist_list->column_types[PLAYLIST_LIST_COL_SONG_FILE_BASENAME] = G_TYPE_STRING;
 	playlist_list->column_types[PLAYLIST_LIST_COL_SONG_ARTIST] = G_TYPE_STRING;
 	playlist_list->column_types[PLAYLIST_LIST_COL_SONG_ALBUM] = G_TYPE_STRING;
 	playlist_list->column_types[PLAYLIST_LIST_COL_SONG_TITLE] = G_TYPE_STRING;
@@ -861,6 +866,13 @@ playlist_list_get_value(GtkTreeModel * tree_model,
 		case PLAYLIST_LIST_COL_SONG_FILE:
 			g_value_set_string(value, song->file);
 			break;
+		case PLAYLIST_LIST_COL_SONG_FILE_BASENAME:
+			{
+				gchar *path = g_path_get_basename(song->file);
+				g_value_set_string(value, path);
+				q_free(path);
+				break;
+			}
 		case PLAYLIST_LIST_COL_SONG_ARTIST:
 			g_value_set_string(value, song->artist);
 			break;
@@ -923,7 +935,7 @@ playlist_list_get_value(GtkTreeModel * tree_model,
 			g_value_set_string(value, song->comment);
 			break;                                			
 		case PLAYLIST_LIST_COL_SONG_POS:
-			g_value_set_int(value, song->pos);
+			g_value_set_int(value, song->pos+1);
 			break;
 		case PLAYLIST_LIST_COL_SONG_ID:
 			g_value_set_int(value, song->id);
@@ -932,7 +944,7 @@ playlist_list_get_value(GtkTreeModel * tree_model,
 		case PLAYLIST_LIST_COL_ICON_ID:
 			if (song->pos ==
 					PLAYLIST_LIST(tree_model)->current_song_pos) {
-				g_value_set_string(value, "gtk-media-play");
+				g_value_set_string(value, "media-playback-start");
 			} else if (strstr(song->file, "://")) {
 				g_value_set_string(value, "media-stream");
 			} else {
@@ -1129,3 +1141,28 @@ CustomList *playlist_list_new(void)
 
 	return newcustomlist;
 }
+
+
+
+/**
+ * Node reffing 
+ */
+
+void playlist_list_ref_node(GtkTreeModel *model, GtkTreeIter *iter)
+{
+  /*printf("ref node: %i\n",GPOINTER_TO_INT(iter->user_data)); 
+*/
+}
+void playlist_list_unref_node(GtkTreeModel *model, GtkTreeIter *iter)
+{
+/*  printf("unref node: %i\n",GPOINTER_TO_INT(iter->user_data)); 
+  if(PLAYLIST_LIST(model)->playlist[GPOINTER_TO_INT(iter->user_data)])
+  {
+    mpd_freeSong(PLAYLIST_LIST(model)->playlist[GPOINTER_TO_INT(iter->user_data)]);
+    PLAYLIST_LIST(model)->playlist[GPOINTER_TO_INT(iter->user_data)] = NULL;
+    PLAYLIST_LIST(model)->loaded--;
+    g_signal_emit(PLAYLIST_LIST(model), playlist_list_signals[TOTAL_TIME_CHANGED],0,0);
+    printf("%i\n", PLAYLIST_LIST(model)->loaded);
+  }
+*/
+}
