@@ -23,14 +23,14 @@
 #include <string.h>
 #include <glade/glade.h>
 #include <config.h>
-#include "bacon-volume.h"
+#include "bacon/bacon-volume.h"
 #include "main.h"
 #include "misc.h"
 #include "playlist3.h"
 /* every part split out over multiple files */
-#include "playlist3-file-browser.h"
-#include "playlist3-artist-browser.h"
-#include "playlist3-current-playlist-browser.h"
+#include "browsers/playlist3-file-browser.h"
+#include "browsers/playlist3-artist-browser.h"
+#include "browsers/playlist3-current-playlist-browser.h"
 #include "revision.h"
 #include "id3info.h"
 
@@ -82,6 +82,9 @@ void playlist_player_cover_art_pressed(GtkEventBox *, GdkEventButton *);
 void hide_on_close_enable_tb(GtkToggleButton *but);
 void pl3_window_fullscreen(void);
 gboolean pl3_close(void);
+static void pl3_update_profiles_menu(GmpcProfiles *prof,const int changed, const int col, const gchar *id);
+
+static void pl3_profiles_changed(GmpcProfiles *prof,const int changed, const int col, const gchar *id);
 
 /* Old category browser style */
 static int old_type = -1;
@@ -325,7 +328,7 @@ void pl3_cat_sel_changed()
 		 */
 		if(old_type != type )
 		{
-			if(old_type != -1)
+			if(old_type != -1 && plugins[plugin_get_pos(old_type)]->browser->unselected != NULL)
 			{
 				plugins[plugin_get_pos(old_type)]->browser->unselected(container);
 			}
@@ -333,7 +336,10 @@ void pl3_cat_sel_changed()
 		}
 		pl3_push_rsb_message("");
 		/** if type changed give a selected signal */
-		if(old_type != type)plugins[plugin_get_pos(type)]->browser->selected(container);
+		if((old_type != type) && (plugins[plugin_get_pos(type)]->browser->selected != NULL))
+		{ 
+			plugins[plugin_get_pos(type)]->browser->selected(container);
+		}
 		/**
 		 * update old value, so get_selected_category is correct before calling selection_changed
 		 */
@@ -348,7 +354,7 @@ void pl3_cat_sel_changed()
 	}
 	else
 	{
-		if(old_type != -1)
+		if(old_type != -1 && plugins[plugin_get_pos(old_type)]->browser->unselected)
 		{
 			plugins[plugin_get_pos(old_type)]->browser->unselected(container);
 		}
@@ -402,11 +408,13 @@ void pl3_option_menu_activate(void)
 	if(menu_items)
 	{
 		gtk_widget_show_all(menu);
-		gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pl3_xml, "menu_option")), menu);
+    gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pl3_xml, "menu_option")), menu);
+    gtk_widget_set_sensitive(GTK_WIDGET(glade_xml_get_widget(pl3_xml, "menu_option")),TRUE);
 	}
 	else{
 		gtk_widget_destroy(menu);
-	}
+    gtk_widget_set_sensitive(GTK_WIDGET(glade_xml_get_widget(pl3_xml, "menu_option")),FALSE);
+  }
 
 }
 int pl3_cat_tree_button_release_event(GtkTreeView *tree, GdkEventButton *event)
@@ -665,7 +673,6 @@ int pl3_hide()
 {
 	if(!tray_availible())
 	{
-		printf("No tray availible\n");
 		return 1;
 	}
 	if(pl3_xml != NULL && !pl3_hidden )
@@ -879,13 +886,14 @@ void create_playlist3 ()
 				);
 	}
 
+
 	tree = glade_xml_get_widget (pl3_xml, "cat_tree");
 	gtk_tree_view_set_model (GTK_TREE_VIEW (tree), GTK_TREE_MODEL (pl3_tree));
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	column = gtk_tree_view_column_new ();
 	gtk_tree_view_column_pack_start (column, renderer, FALSE);
-	gtk_tree_view_column_set_attributes (column, renderer, "stock-id",3,"stock-size",5,NULL);
+	gtk_tree_view_column_set_attributes (column, renderer, "icon-name",3,"stock-size",5,NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
 	/* insert the column in the tree */
@@ -915,7 +923,7 @@ void create_playlist3 ()
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(pl3_xml, "cb_cat_selector")),renderer,FALSE); 
 	gtk_cell_layout_add_attribute(GTK_CELL_LAYOUT(glade_xml_get_widget(pl3_xml, "cb_cat_selector")),renderer,
-			"stock-id", 1);                                                                                          	
+			"icon-name", 1);                                                                                          	
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(glade_xml_get_widget(pl3_xml, "cb_cat_selector")),renderer,TRUE); 
@@ -1023,7 +1031,10 @@ void create_playlist3 ()
 	gtk_widget_hide(glade_xml_get_widget(pl3_xml, "metaimage_artist_art"));
 
 	pl3_update_go_menu();	
-	pl3_update_profiles_menu();
+	/* make it update itself */
+	pl3_update_profiles_menu(gmpc_profiles,PROFILE_ADDED,-1, NULL);
+	g_signal_connect(G_OBJECT(gmpc_profiles), "changed", G_CALLBACK(pl3_update_profiles_menu), NULL);
+	g_signal_connect(G_OBJECT(gmpc_profiles), "changed", G_CALLBACK(pl3_profiles_changed), NULL);
 
 	/**
 	 * Set as drag destination
@@ -1713,7 +1724,6 @@ static void pl3_profile_selected(GtkRadioMenuItem *radio,gpointer data)
 		gchar *uid = g_object_get_data(G_OBJECT(radio), "uid");
 		if(!uid)
 		{
-			printf("no uid found\n");
 			return;
 		}
 		connection_set_current_profile(uid);
@@ -1724,13 +1734,34 @@ static void pl3_profile_selected(GtkRadioMenuItem *radio,gpointer data)
 		}
 	}
 }
+static void pl3_profiles_changed(GmpcProfiles *prof,const int changed, const int col, const gchar *id)
+{
+	if(changed == PROFILE_ADDED)
+	{
+		gchar *message = g_strdup_printf("%s '%s' %s  ", _("Profile"), gmpc_profiles_get_name(prof,id), _("added"));
+		pl3_push_statusbar_message(message);
+		g_free(message);
+	}
+	else if(changed == PROFILE_COL_CHANGED && col == PROFILE_COL_HOSTNAME)
+	{
+		gchar *message = g_strdup_printf("%s '%s' %s %s", _("Profile"), gmpc_profiles_get_name(prof,id), _("changed hostname to:"), gmpc_profiles_get_hostname(prof,id));
+		pl3_push_statusbar_message(message);
+		g_free(message);
+	}
 
-void pl3_update_profiles_menu(void)
+}
+static void pl3_update_profiles_menu(GmpcProfiles *prof,const int changed, const int col, const gchar *id)
 {
 	int items = 0;
 	GtkWidget *menu = NULL;
-	gchar *current = connection_get_current_profile();
-	conf_mult_obj *iter, *mult;
+	gchar *current = gmpc_profiles_get_current(gmpc_profiles);
+	GList *iter, *mult;
+	/* check if there is anything changed that is important for us. */
+	if(changed == PROFILE_COL_CHANGED && col != PROFILE_COL_NAME)
+	{
+		q_free(current);
+		return;
+	}
 	/***
 	 * Remove any old menu
 	 */
@@ -1740,23 +1771,22 @@ void pl3_update_profiles_menu(void)
 	 */
 	menu = gtk_menu_new();
 
-	mult = cfg_get_class_list(profiles);
+	mult = gmpc_profiles_get_profiles_ids(gmpc_profiles); 
 	if(mult)
 	{
 		GSList *group = NULL;
 		iter = mult;
 		do{
 			/** Get profile name */
-			gchar *value = cfg_get_single_value_as_string_with_default(profiles, iter->key, "name", "Name");
+			gchar *value = gmpc_profiles_get_name(gmpc_profiles, (char *)iter->data); 
 			GtkWidget *item	= gtk_radio_menu_item_new_with_label(group,value);
-			q_free(value);	
 			/* get new group */
 			group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(item));	
 			/* add to the menu */
 			gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 
 			/* check the current profile */
-			if(!strcmp(iter->key, current))
+			if(!strcmp((char *)(iter->data), current))
 			{
 				gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), TRUE);
 			}
@@ -1767,13 +1797,15 @@ void pl3_update_profiles_menu(void)
 			g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(pl3_profile_selected), NULL);
 
 			/** Attach the uid to the handler */
-			value = g_strdup(iter->key);
+			value = g_strdup((char *)(iter->data));
 			g_object_set_data_full(G_OBJECT(item), "uid", value, g_free);
 
-			iter = iter->next;
 			items++;
-		}while(iter);
-		cfg_free_multiple(mult);
+		}while((iter = g_list_next(iter)));
+		g_list_foreach(mult, (GFunc)g_free, NULL);
+		g_list_free(mult);
+
+
 	}
 
 	/**
@@ -1788,4 +1820,5 @@ void pl3_update_profiles_menu(void)
 		gtk_widget_set_sensitive(glade_xml_get_widget(pl3_xml, "menu_profiles"), FALSE);
 		gtk_widget_destroy(menu);
 	}
+	g_free(current);
 }
