@@ -182,35 +182,38 @@ static gboolean tray_motion_cb (GtkWidget *evt, GdkEventCrossing *event1, gpoint
 		gtk_widget_set_app_paintable(GTK_WIDGET(tip), TRUE);
 		g_signal_connect(G_OBJECT(tip), "expose-event", G_CALLBACK(tip_expose_event), NULL);
 
-		alimg = gmpc_metaimage_new(META_ALBUM_ART);
-		gmpc_metaimage_set_connection(GMPC_METAIMAGE(alimg), connection);
-		gmpc_metaimage_set_size(GMPC_METAIMAGE(alimg), 80);
-		gmpc_metaimage_set_no_cover_icon(GMPC_METAIMAGE(alimg),"gmpc"); 
-		state = mpd_player_get_state(connection);
-		if(state == MPD_PLAYER_PLAY || state == MPD_PLAYER_PAUSE)		
-		{
-			gmpc_metaimage_update_cover(GMPC_METAIMAGE(alimg), connection, MPD_CST_SONGID,NULL);
-		}
-		else 
-		{
-			gmpc_metaimage_set_cover_na(GMPC_METAIMAGE(alimg));
-		}
-		gtk_widget_show(alimg);
+    if(cfg_get_single_value_as_int_with_default(config, "tray-icon", "show-image", TRUE))
+    {
+      alimg = gmpc_metaimage_new(META_ALBUM_ART);
+      gmpc_metaimage_set_connection(GMPC_METAIMAGE(alimg), connection);
+      gmpc_metaimage_set_size(GMPC_METAIMAGE(alimg), 80);
+      gmpc_metaimage_set_no_cover_icon(GMPC_METAIMAGE(alimg),"gmpc"); 
+      state = mpd_player_get_state(connection);
+      if(state == MPD_PLAYER_PLAY || state == MPD_PLAYER_PAUSE)		
+      {
+        gmpc_metaimage_update_cover(GMPC_METAIMAGE(alimg), connection, MPD_CST_SONGID,NULL);
+      }
+      else 
+      {
+        gmpc_metaimage_set_cover_na(GMPC_METAIMAGE(alimg));
+      }
+      gtk_widget_show(alimg);
 
-		event = gtk_event_box_new();
-
-		gtk_widget_modify_bg(GTK_WIDGET(event),GTK_STATE_NORMAL, &(pl3_win->style->bg[GTK_STATE_SELECTED]));
-		gtk_widget_set_size_request(event, 86,86);
-		gtk_container_add(GTK_CONTAINER(event), alimg);
-		gtk_widget_show_all(event);	
+      event = gtk_event_box_new();
 
+      gtk_widget_modify_bg(GTK_WIDGET(event),GTK_STATE_NORMAL, &(pl3_win->style->bg[GTK_STATE_SELECTED]));
+      gtk_widget_set_size_request(event, 86,86);
+      gtk_container_add(GTK_CONTAINER(event), alimg);
+      gtk_widget_show_all(event);	
+      gtk_box_pack_start(GTK_BOX(hbox), event,FALSE, TRUE,0);
+    }
 		/**
 		 * Add tip to event
 		 */
 		gtk_container_add(GTK_CONTAINER(tip), event2);
 		gtk_widget_show(event2);
 		gtk_container_add(GTK_CONTAINER(event2), hbox);
-		gtk_box_pack_start(GTK_BOX(hbox), event,FALSE, TRUE,0);
+
 
 		vbox = gtk_vbox_new(FALSE,0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 3);
@@ -418,11 +421,11 @@ static void tray_icon_song_change()
 void tray_icon_connection_changed(MpdObj *mi, int connect)
 {
 	if(connect){
-		if(tray_icon)gtk_image_set_from_stock(GTK_IMAGE(logo), "gmpc-tray", -1);
+		if(tray_icon)gtk_image_set_from_icon_name(GTK_IMAGE(logo), "gmpc-tray", -1);
 		tray_icon_state_change();
 	}
 	else{
-		if(tray_icon)gtk_image_set_from_stock(GTK_IMAGE(logo), "gmpc-tray-disconnected", -1);
+		if(tray_icon)gtk_image_set_from_icon_name(GTK_IMAGE(logo), "gmpc-tray-disconnected", -1);
 	}
 }
 
@@ -431,7 +434,7 @@ static void tray_icon_state_change()
 	int state = mpd_player_get_state(connection);
 	if(state == MPD_PLAYER_STOP || state == MPD_PLAYER_UNKNOWN)
 	{
-		if(tray_icon)gtk_image_set_from_stock(GTK_IMAGE(logo), "gmpc-tray", -1);
+		if(tray_icon)gtk_image_set_from_icon_name(GTK_IMAGE(logo), "gmpc-tray", -1);
 		tray_leave_cb(NULL, NULL,0);
 		/*if(cover_pb)
 		  {
@@ -441,11 +444,11 @@ static void tray_icon_state_change()
 	}
 	else if(state == MPD_PLAYER_PLAY){
 
-		if(tray_icon)	gtk_image_set_from_stock(GTK_IMAGE(logo), "gmpc-tray-play", -1);
+		if(tray_icon)	gtk_image_set_from_icon_name(GTK_IMAGE(logo), "gmpc-tray-play", -1);
 		tray_icon_song_change();
 	}
 	else if(state == MPD_PLAYER_PAUSE){
-		if(tray_icon)gtk_image_set_from_stock(GTK_IMAGE(logo), "gmpc-tray-pause", -1);
+		if(tray_icon)gtk_image_set_from_icon_name(GTK_IMAGE(logo), "gmpc-tray-pause", -1);
 	}
 	if(tray_icon)
 	{
@@ -528,29 +531,21 @@ static int  tray_mouse_menu(GtkWidget *wid, GdkEventButton *event)
 		{
 			if(mpd_server_check_command_allowed(connection, "play"))
 			{
-				item = gtk_image_menu_item_new_with_mnemonic(_("Pl_ay/Pause"));
-				gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-						gtk_image_new_from_stock("gtk-media-play", GTK_ICON_SIZE_MENU));
+				item = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_PLAY, NULL);
 				gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 				g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(play_song), NULL);
 
 
-				item = gtk_image_menu_item_new_with_mnemonic(_("_Stop"));
-				gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-						gtk_image_new_from_stock("gtk-media-stop", GTK_ICON_SIZE_MENU));
+				item = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_STOP, NULL);
 				gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 				g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(stop_song), NULL);
 
-				item = gtk_image_menu_item_new_with_mnemonic(_("_Next"));
-				gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-						gtk_image_new_from_stock("gtk-media-next", GTK_ICON_SIZE_MENU));
+				item = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_NEXT, NULL);
 				gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 				g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(next_song), NULL);
 
 
-				item = gtk_image_menu_item_new_with_mnemonic(_("_Previous"));
-				gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-						gtk_image_new_from_stock("gtk-media-previous", GTK_ICON_SIZE_MENU));
+				item = gtk_image_menu_item_new_from_stock(GTK_STOCK_MEDIA_PREVIOUS, NULL);
 				gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
 				g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(prev_song), NULL);
 				item = gtk_separator_menu_item_new();
@@ -636,7 +631,7 @@ static int create_tray_icon()
 	tray_icon = egg_tray_icon_new(_("Gnome Music Player Client"));
 	event = gtk_event_box_new();
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(event), FALSE);
-	logo = 	gtk_image_new_from_stock("gmpc-tray-disconnected",-1);
+	logo = 	gtk_image_new_from_icon_name("gmpc-tray-disconnected",-1);
 
 
 
@@ -672,7 +667,7 @@ static void TrayStatusChanged(MpdObj *mi, ChangedStatusType what, void *userdata
 	{
 		tray_icon_state_change();
 	}
-	else if(what&(MPD_CST_SONGID|MPD_CST_PLAYLIST|MPD_CST_SONGPOS))
+	else if(what&(MPD_CST_SONGID/*|MPD_CST_PLAYLIST|MPD_CST_SONGPOS)*/))
 	{
 		if(!tip)
 		{
